==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/instance/impl/PendingEventSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instance.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceSet;
import io.ciera.tool.sql.ooaofooa.instance.DataItemValueSet;
import io.ciera.tool.sql.ooaofooa.instance.EventQueueEntrySet;
import io.ciera.tool.sql.ooaofooa.instance.I_INSSet;
import io.ciera.tool.sql.ooaofooa.instance.PendingEvent;
import io.ciera.tool.sql.ooaofooa.instance.PendingEventSet;
import io.ciera.tool.sql.ooaofooa.instance.SelfQueueEntrySet;
import io.ciera.tool.sql.ooaofooa.instance.TimerSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.ComponentInstanceSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.DataItemValueSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.EventQueueEntrySetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.I_INSSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.PendingEventSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.SelfQueueEntrySetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.TimerSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;

import java.util.Arrays;
import java.util.List;


public class PendingEventSetImpl extends InstanceSet<PendingEventSet,PendingEvent> implements PendingEventSet {

    // attributes
    @Override
    public void setNext_self_Event_ID( UniqueId ref_next_self_Event_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setNext_self_Event_ID( ref_next_self_Event_ID );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setLabel( m_Label );
    }
    @Override
    public void setSent_By_Inst_ID( UniqueId ref_Sent_By_Inst_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setSent_By_Inst_ID( ref_Sent_By_Inst_ID );
    }
    @Override
    public void setEvent_ID( UniqueId m_Event_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setEvent_ID( m_Event_ID );
    }
    @Override
    public void setNextEvent_ID( UniqueId ref_nextEvent_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setNextEvent_ID( ref_nextEvent_ID );
    }
    @Override
    public void setExecution_Engine_ID( UniqueId ref_Execution_Engine_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setExecution_Engine_ID( ref_Execution_Engine_ID );
    }
    @Override
    public void setIsCreation( boolean m_isCreation ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setIsCreation( m_isCreation );
    }
    @Override
    public void setCIE_ID( UniqueId m_CIE_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setCIE_ID( m_CIE_ID );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setSMevt_ID( ref_SMevt_ID );
    }
    @Override
    public void setTarget_Inst_ID( UniqueId ref_Target_Inst_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setTarget_Inst_ID( ref_Target_Inst_ID );
    }
    @Override
    public void setIsExecuting( boolean m_isExecuting ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setIsExecuting( m_isExecuting );
    }
    @Override
    public void setOriginating_Execution_Engine_ID( UniqueId ref_Originating_Execution_Engine_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setOriginating_Execution_Engine_ID( ref_Originating_Execution_Engine_ID );
    }
    @Override
    public void setSent_By_CIE_ID( UniqueId m_Sent_By_CIE_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setSent_By_CIE_ID( m_Sent_By_CIE_ID );
    }


    // selections
    @Override
    public StateMachineEventSet R2906_is_instance_of_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( PendingEvent pendingevent : this ) statemachineeventset.add( pendingevent.R2906_is_instance_of_StateMachineEvent() );
        return statemachineeventset;
    }
    @Override
    public I_INSSet R2907_is_pending_for_I_INS() throws XtumlException {
        I_INSSet i_insset = new I_INSSetImpl();
        for ( PendingEvent pendingevent : this ) i_insset.add( pendingevent.R2907_is_pending_for_I_INS() );
        return i_insset;
    }
    @Override
    public PendingEventSet R2908_will_be_processed_after_PendingEvent() throws XtumlException {
        PendingEventSet pendingeventset = new PendingEventSetImpl();
        for ( PendingEvent pendingevent : this ) pendingeventset.add( pendingevent.R2908_will_be_processed_after_PendingEvent() );
        return pendingeventset;
    }
    @Override
    public PendingEventSet R2908_will_be_processed_before_PendingEvent() throws XtumlException {
        PendingEventSet pendingeventset = new PendingEventSetImpl();
        for ( PendingEvent pendingevent : this ) pendingeventset.add( pendingevent.R2908_will_be_processed_before_PendingEvent() );
        return pendingeventset;
    }
    @Override
    public DataItemValueSet R2933_DataItemValue() throws XtumlException {
        DataItemValueSet dataitemvalueset = new DataItemValueSetImpl();
        for ( PendingEvent pendingevent : this ) dataitemvalueset.addAll( pendingevent.R2933_DataItemValue() );
        return dataitemvalueset;
    }
    @Override
    public I_INSSet R2935_targets_I_INS() throws XtumlException {
        I_INSSet i_insset = new I_INSSetImpl();
        for ( PendingEvent pendingevent : this ) i_insset.add( pendingevent.R2935_targets_I_INS() );
        return i_insset;
    }
    @Override
    public I_INSSet R2937_was_sent_from_I_INS() throws XtumlException {
        I_INSSet i_insset = new I_INSSetImpl();
        for ( PendingEvent pendingevent : this ) i_insset.add( pendingevent.R2937_was_sent_from_I_INS() );
        return i_insset;
    }
    @Override
    public PendingEventSet R2939_will_be_processed_after_PendingEvent() throws XtumlException {
        PendingEventSet pendingeventset = new PendingEventSetImpl();
        for ( PendingEvent pendingevent : this ) pendingeventset.add( pendingevent.R2939_will_be_processed_after_PendingEvent() );
        return pendingeventset;
    }
    @Override
    public PendingEventSet R2939_will_be_processed_before_PendingEvent() throws XtumlException {
        PendingEventSet pendingeventset = new PendingEventSetImpl();
        for ( PendingEvent pendingevent : this ) pendingeventset.add( pendingevent.R2939_will_be_processed_before_PendingEvent() );
        return pendingeventset;
    }
    @Override
    public TimerSet R2940_delivered_by_Timer() throws XtumlException {
        TimerSet timerset = new TimerSetImpl();
        for ( PendingEvent pendingevent : this ) timerset.add( pendingevent.R2940_delivered_by_Timer() );
        return timerset;
    }
    @Override
    public EventQueueEntrySet R2944_EventQueueEntry() throws XtumlException {
        EventQueueEntrySet eventqueueentryset = new EventQueueEntrySetImpl();
        for ( PendingEvent pendingevent : this ) eventqueueentryset.add( pendingevent.R2944_EventQueueEntry() );
        return eventqueueentryset;
    }
    @Override
    public SelfQueueEntrySet R2946_SelfQueueEntry() throws XtumlException {
        SelfQueueEntrySet selfqueueentryset = new SelfQueueEntrySetImpl();
        for ( PendingEvent pendingevent : this ) selfqueueentryset.add( pendingevent.R2946_SelfQueueEntry() );
        return selfqueueentryset;
    }
    @Override
    public ComponentInstanceSet R2964_is_pending_in_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( PendingEvent pendingevent : this ) componentinstanceset.add( pendingevent.R2964_is_pending_in_ComponentInstance() );
        return componentinstanceset;
    }
    @Override
    public ComponentInstanceSet R2976_originates_from_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( PendingEvent pendingevent : this ) componentinstanceset.add( pendingevent.R2976_originates_from_ComponentInstance() );
        return componentinstanceset;
    }


    @Override
    public PendingEvent nullElement() {
        return PendingEventImpl.EMPTY_PENDINGEVENT;
    }

    @Override
    public PendingEventSet emptySet() {
      return new PendingEventSetImpl();
    }

    @Override
    public PendingEventSet value() {
        return this;
    }

    @Override
    public List<PendingEvent> elements() {
        return Arrays.asList(toArray(new PendingEvent[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/instance/impl/PendingEventSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instance.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceSet;
import io.ciera.tool.sql.ooaofooa.instance.DataItemValueSet;
import io.ciera.tool.sql.ooaofooa.instance.EventQueueEntrySet;
import io.ciera.tool.sql.ooaofooa.instance.I_INSSet;
import io.ciera.tool.sql.ooaofooa.instance.PendingEvent;
import io.ciera.tool.sql.ooaofooa.instance.PendingEventSet;
import io.ciera.tool.sql.ooaofooa.instance.SelfQueueEntrySet;
import io.ciera.tool.sql.ooaofooa.instance.TimerSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.ComponentInstanceSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.DataItemValueSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.EventQueueEntrySetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.I_INSSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.PendingEventSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.SelfQueueEntrySetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.TimerSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class PendingEventSetImpl extends InstanceSet<PendingEventSet,PendingEvent> implements PendingEventSet {

    public PendingEventSetImpl() {
    }

    public PendingEventSetImpl(Comparator<? super PendingEvent> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setNext_self_Event_ID( UniqueId ref_next_self_Event_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setNext_self_Event_ID( ref_next_self_Event_ID );
    }
    @Override
    public void setIsExecuting( boolean m_isExecuting ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setIsExecuting( m_isExecuting );
    }
    @Override
    public void setSent_By_CIE_ID( UniqueId m_Sent_By_CIE_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setSent_By_CIE_ID( m_Sent_By_CIE_ID );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setLabel( m_Label );
    }
    @Override
    public void setExecution_Engine_ID( UniqueId ref_Execution_Engine_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setExecution_Engine_ID( ref_Execution_Engine_ID );
    }
    @Override
    public void setTarget_Inst_ID( UniqueId ref_Target_Inst_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setTarget_Inst_ID( ref_Target_Inst_ID );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setSMevt_ID( ref_SMevt_ID );
    }
    @Override
    public void setCIE_ID( UniqueId m_CIE_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setCIE_ID( m_CIE_ID );
    }
    @Override
    public void setOriginating_Execution_Engine_ID( UniqueId ref_Originating_Execution_Engine_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setOriginating_Execution_Engine_ID( ref_Originating_Execution_Engine_ID );
    }
    @Override
    public void setSent_By_Inst_ID( UniqueId ref_Sent_By_Inst_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setSent_By_Inst_ID( ref_Sent_By_Inst_ID );
    }
    @Override
    public void setEvent_ID( UniqueId m_Event_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setEvent_ID( m_Event_ID );
    }
    @Override
    public void setNextEvent_ID( UniqueId ref_nextEvent_ID ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setNextEvent_ID( ref_nextEvent_ID );
    }
    @Override
    public void setIsCreation( boolean m_isCreation ) throws XtumlException {
        for ( PendingEvent pendingevent : this ) pendingevent.setIsCreation( m_isCreation );
    }


    // selections
    @Override
    public StateMachineEventSet R2906_is_instance_of_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( PendingEvent pendingevent : this ) statemachineeventset.add( pendingevent.R2906_is_instance_of_StateMachineEvent() );
        return statemachineeventset;
    }
    @Override
    public I_INSSet R2907_is_pending_for_I_INS() throws XtumlException {
        I_INSSet i_insset = new I_INSSetImpl();
        for ( PendingEvent pendingevent : this ) i_insset.add( pendingevent.R2907_is_pending_for_I_INS() );
        return i_insset;
    }
    @Override
    public PendingEventSet R2908_will_be_processed_after_PendingEvent() throws XtumlException {
        PendingEventSet pendingeventset = new PendingEventSetImpl();
        for ( PendingEvent pendingevent : this ) pendingeventset.add( pendingevent.R2908_will_be_processed_after_PendingEvent() );
        return pendingeventset;
    }
    @Override
    public PendingEventSet R2908_will_be_processed_before_PendingEvent() throws XtumlException {
        PendingEventSet pendingeventset = new PendingEventSetImpl();
        for ( PendingEvent pendingevent : this ) pendingeventset.add( pendingevent.R2908_will_be_processed_before_PendingEvent() );
        return pendingeventset;
    }
    @Override
    public DataItemValueSet R2933_DataItemValue() throws XtumlException {
        DataItemValueSet dataitemvalueset = new DataItemValueSetImpl();
        for ( PendingEvent pendingevent : this ) dataitemvalueset.addAll( pendingevent.R2933_DataItemValue() );
        return dataitemvalueset;
    }
    @Override
    public I_INSSet R2935_targets_I_INS() throws XtumlException {
        I_INSSet i_insset = new I_INSSetImpl();
        for ( PendingEvent pendingevent : this ) i_insset.add( pendingevent.R2935_targets_I_INS() );
        return i_insset;
    }
    @Override
    public I_INSSet R2937_was_sent_from_I_INS() throws XtumlException {
        I_INSSet i_insset = new I_INSSetImpl();
        for ( PendingEvent pendingevent : this ) i_insset.add( pendingevent.R2937_was_sent_from_I_INS() );
        return i_insset;
    }
    @Override
    public PendingEventSet R2939_will_be_processed_after_PendingEvent() throws XtumlException {
        PendingEventSet pendingeventset = new PendingEventSetImpl();
        for ( PendingEvent pendingevent : this ) pendingeventset.add( pendingevent.R2939_will_be_processed_after_PendingEvent() );
        return pendingeventset;
    }
    @Override
    public PendingEventSet R2939_will_be_processed_before_PendingEvent() throws XtumlException {
        PendingEventSet pendingeventset = new PendingEventSetImpl();
        for ( PendingEvent pendingevent : this ) pendingeventset.add( pendingevent.R2939_will_be_processed_before_PendingEvent() );
        return pendingeventset;
    }
    @Override
    public TimerSet R2940_delivered_by_Timer() throws XtumlException {
        TimerSet timerset = new TimerSetImpl();
        for ( PendingEvent pendingevent : this ) timerset.add( pendingevent.R2940_delivered_by_Timer() );
        return timerset;
    }
    @Override
    public EventQueueEntrySet R2944_EventQueueEntry() throws XtumlException {
        EventQueueEntrySet eventqueueentryset = new EventQueueEntrySetImpl();
        for ( PendingEvent pendingevent : this ) eventqueueentryset.add( pendingevent.R2944_EventQueueEntry() );
        return eventqueueentryset;
    }
    @Override
    public SelfQueueEntrySet R2946_SelfQueueEntry() throws XtumlException {
        SelfQueueEntrySet selfqueueentryset = new SelfQueueEntrySetImpl();
        for ( PendingEvent pendingevent : this ) selfqueueentryset.add( pendingevent.R2946_SelfQueueEntry() );
        return selfqueueentryset;
    }
    @Override
    public ComponentInstanceSet R2964_is_pending_in_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( PendingEvent pendingevent : this ) componentinstanceset.add( pendingevent.R2964_is_pending_in_ComponentInstance() );
        return componentinstanceset;
    }
    @Override
    public ComponentInstanceSet R2976_originates_from_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( PendingEvent pendingevent : this ) componentinstanceset.add( pendingevent.R2976_originates_from_ComponentInstance() );
        return componentinstanceset;
    }


    @Override
    public PendingEvent nullElement() {
        return PendingEventImpl.EMPTY_PENDINGEVENT;
    }

    @Override
    public PendingEventSet emptySet() {
      return new PendingEventSetImpl();
    }

    @Override
    public PendingEventSet emptySet(Comparator<? super PendingEvent> comp) {
      return new PendingEventSetImpl(comp);
    }

    @Override
    public PendingEventSet value() {
        return this;
    }

    @Override
    public List<PendingEvent> elements() {
        return Arrays.asList(toArray(new PendingEvent[0]));
    }

}
